@@ -45,7 +45,7 @@ borders_download = function(type, outdir = ".", unzip = TRUE, ...) {
 
   if (any(status %in% c("error", "warning"))) {
     err_print()
-    return("connection error")
+    return(invisible("connection error"))
   }
 
   if (unzip) {
