@@ -79,7 +79,7 @@ models3D_download = function(county = NULL, TERYT = NULL, LOD = "LOD1",
 
     if (any(status %in% c("error", "warning"))) {
       err_print()
-      return("connection error")
+      return(invisible("connection error"))
     }
 
     if (unzip) {
